@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2022 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2024 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -186,6 +186,7 @@ $Data{'country'}{'iso'}{'orig'}{'name'} = {
    "Réunion"                                 => "Reunion",
    "Saint Barthélemy"                        => "Saint Barthelemy",
    "Western Sahara*"                         => "Western Sahara",
+   "Türkiye"                                => "Turkiye",
 };
 
 $Data{'country'}{'iso'}{'ignore'} = {
@@ -245,6 +246,7 @@ $Data{'country'}{'un'}{'orig'}{'name'} = {
    "R&#233;union"                            => "Reunion",
    "Saint Barth&#233;lemy"                   => "Saint Barthelemy",
    "C&#244;te d’Ivoire"                  => "Cote d'Ivoire",
+   "T&#252;rkiye"                            => "Turkiye",
 };
 
 $Data{'country'}{'un'}{'new'} = {
@@ -258,63 +260,22 @@ $Data{'country'}{'un'}{'new'} = {
 $Data{'country'}{'genc'}{'orig'}{'name'} = {
    "CÔTE D’IVOIRE"                           => "Cote d'Ivoire",
    "CURAÇAO",                                => "Curacao",
-   "AKROTIRI"                                => "Akrotiri",
    "ASHMORE AND CARTIER ISLANDS"             => "Ashmore and Cartier Islands",
-   "BAKER ISLAND"                            => "Baker Island",
-   "BASSAS DA INDIA"                         => "Bassas Da India",
-   "BONAIRE, SINT EUSTATIUS, AND SABA"       => "Bonaire, Sint Eustatius, and Saba",
-   "CLIPPERTON ISLAND"                       => "Clipperton Island",
-   "CORAL SEA ISLANDS"                       => "Coral Sea Islands",
-   "DHEKELIA"                                => "Dhekelia",
-   "DIEGO GARCIA"                            => "Diego Garcia",
-   "ENTITY 1"                                => "Entity 1",
-   "ENTITY 2"                                => "Entity 2",
-   "ENTITY 3"                                => "Entity 3",
-   "ENTITY 4"                                => "Entity 4",
-   "ENTITY 5"                                => "Entity 5",
-   "ENTITY 6"                                => "Entity 6",
-   "EUROPA ISLAND"                           => "Europa Island",
-   "GAZA STRIP"                              => "Gaza Strip",
-   "GLORIOSO ISLANDS"                        => "Glorioso Islands",
-   "GUANTANAMO BAY NAVAL BASE"               => "Guantanamo Bay Naval Base",
-   "HOWLAND ISLAND"                          => "Howland Island",
-   "JAN MAYEN"                               => "Jan Mayen",
-   "JARVIS ISLAND"                           => "Jarvis Island",
-   "JOHNSTON ATOLL"                          => "Johnston Atoll",
    "JUAN DE NOVA ISLAND"                     => "Juan de Nova Island",
-   "KINGMAN REEF"                            => "Kingman Reef",
-   "KOREA, NORTH"                            => "Korea, North",
-   "KOREA, SOUTH"                            => "Korea, South",
-   "KOSOVO"                                  => "Kosovo",
-   "LAOS"                                    => "Laos",
-   "MIDWAY ISLANDS"                          => "Midway Islands",
-   "MOLDOVA"                                 => "Moldova",
-   "NAVASSA ISLAND"                          => "Navassa Island",
-   "PALMYRA ATOLL"                           => "Palmyra Atoll",
-   "PARACEL ISLANDS"                         => "Paracel Islands",
-   "RUSSIA"                                  => "Russia",
    "SAINT HELENA, ASCENSION, AND TRISTAN DA CUNHA" => "Saint Helena, Ascension, and Tristan Da Cunha",
-   "SINT MAARTEN"                            => "Sint Maarten",
    "SOUTH GEORGIA AND SOUTH SANDWICH ISLANDS" => "South Georgia and South Sandwich Islands",
-   "SPRATLY ISLANDS"                         => "Spratly Islands",
-   "SVALBARD"                                => "Svalbard",
-   "TANZANIA"                                => "Tanzania",
-   "TROMELIN ISLAND"                         => "Tromelin Island",
-   "UNKNOWN"                                 => "Unknown",
-   "WAKE ISLAND"                             => "Wake Island",
-   "WEST BANK"                               => "West Bank",
+   "BONAIRE, SINT EUSTATIUS, AND SABA"       => "Bonaire, Sint Eustatius, and Saba",
+   "Åland Islands"                         => "Aland Islands",
 };
 
 $Data{'country'}{'genc'}{'ignore'} = {
-   'name'           => { "ENTITY 1" => 1,
-                         "ENTITY 2" => 1,
-                         "ENTITY 3" => 1,
-                         "ENTITY 4" => 1,
-                         "ENTITY 5" => 1,
-                         "ENTITY 6" => 1,
+   'name'           => {
+                        'Unknown'  => 1,
+                       },
+   'genc-alpha-2'   => {
+                       },
+   'genc-alpha-3'   => {
                        },
-   'genc-alpha-2'   => {},
-   'genc-alpha-3'   => {},
    'genc-numeric'   => {},
 };
 
